import { Input, Space, Table, Tag } from "antd";
import Column from "antd/es/table/Column";
import { useEffect, useState } from "react";
import axiosInstance from "../../api/axios";
import DeviceDetailModal from "./DeviceDetailModal";

const statusColorMap = {
  空闲: "green",
  使用中: "red",
  有预约: "yellow",
  维修中: "gray",
};

export default function Reserve() {
  const [name, setName] = useState(null);
  const [pagination, setPagination] = useState({
    current: 1,
    pageSize: 10,
    total: 0,
  });
  const [devices, setDevices] = useState([]);

  const fetchData = async (pagination, searchName = name) => {
    const data = await axiosInstance.get("/device", {
      params: {
        page: pagination.current,
        size: pagination.pageSize,
        name: searchName,
      },
    });

    setDevices(data.records);
    setPagination({
      ...pagination,
      total: data.total,
    });
  };
  useEffect(() => {
    fetchData(pagination);
  }, []);

  const handlePageChange = (pagination) => {
    fetchData(pagination);
  };

  const [selectedDevice, setSelectedDevice] = useState(null);

  const handleSearch = (value) => {
    setName(value);
    const newPagination = {
      ...pagination,
      current: 1,
    };
    setPagination(newPagination);
    fetchData(newPagination, value);
  };

  return (
    <>
      <Input.Search
        placeholder="请输入设备名称"
        onSearch={handleSearch}
        style={{ width: "200px" }}
        className="m-4"
      />
      <Table
        dataSource={devices}
        pagination={pagination}
        onChange={handlePageChange}
        rowKey="deviceId"
      >
        <Column title="设备名称" key="name" dataIndex="name" />
        <Column
          title="使用要求"
          key="usageRequirement"
          dataIndex="usageRequirement"
          ellipsis="true"
        />
        <Column title="位置" key="location" dataIndex="location" />
        <Column
          title="状态"
          key="state"
          dataIndex="state"
          render={(_, { state }) => (
            <>
              <Tag color={statusColorMap[state]} key="state">
                {state}
              </Tag>
            </>
          )}
        />
        <Column
          title="操作"
          key="action"
          render={(_, record) => (
            <Space size="middle">
              <a onClick={() => setSelectedDevice(record)}>预约</a>
            </Space>
          )}
        />
      </Table>
      <DeviceDetailModal
        visiable={!!selectedDevice}
        device={selectedDevice}
        onclose={() => setSelectedDevice(null)}
      />
    </>
  );
}
